/*		 ITI-FG  Kernel module free public release
 *
 *		     Copyright (C) 1996-2000 GOM mbH.
 *	         Rebenring 33, 38106 Braunschweig, GERMANY
 *		            All rights reserved
 *
 * $Id: itifgReg.h,v 7.0 2000/10/25 09:07:57 cvs Exp $
 *
 */

#ifndef _ITIFGREG_H
#define _ITIFGREG_H

#if defined(linux) && defined(__KERNEL__) || \
    defined(__NetBSD__) && defined(_KERNEL) || \
    !defined(OS_DEFINED)

/* IC-PCI Hardware Reference Manual; Imaging Technology Inc. */
/* Document Number 47-H600002-0[0|1]; March 1995, revised March 1998 */
/* PCI Interface Control Registers (32bit access only), pages 3-17 to 3-24 */
/* *********************************************************************** */
/* PC-DIG Hardware Reference Manual; Imaging Technology Inc. */
/* Document Number 402-00002-00; draft 0 February 1999 */
/* PCI Interface Control Registers (32bit access only), pages 3-18 to 3-25 */
/* *********************************************************************** */

/* R-O   Read-Only Register */
/* W-O   Write-Only Register */
/* R/W   Read/Write Register */
/* R/W1C Clear on Write One to Register */
/* R/W0C Clear on Write Zero to Register */

#ifdef __cplusplus
extern "C" {
#endif

#define ICR_DISABLE		0
#define ICR_ENABLE		1

#define	ICR_REG_SIZE		(16 * sizeof(u_long))

#define ICR_NO_MASK		0xFFFFFFFF	/* no range checking */
#define ICR_NO_MIN		0x00000000
#define ICR_NO_MAX		0xFFFFFFFF
#define ICR_NO_SHIFT		0

#define ICR_MBOX_MASK		ICR_NO_MASK
#define ICR_MBOX_MIN		ICR_NO_MIN
#define ICR_MBOX_MAX		ICR_NO_MAX
#define ICR_MBOX_INIT		0x00000000

/*    u_long	mbox1;		Mailbox Register 0 R/W */

#define ICR_MBOX1_OFFSET	0x00

/*    u_long	mbox2;		Mailbox Register 1 R/W */

#define ICR_MBOX2_OFFSET	0x04

/*    u_long	mbox3;		Mailbox Register 2 R/W */

#define ICR_MBOX3_OFFSET	0x08

/*    u_long	mbox4;		Mailbox Register 3 R/W */

#define ICR_MBOX4_OFFSET	0x0C

/*    u_long	reserved_1[5];	not used 0x10, 0x14, 0x18, 0x1C, 0x20 */

/*    u_long	bmdst;		Bus Master Destination Address */
/*				0:31/ 32bit boundary - R/W (IC-PCI)
				                       R/O (PC-DIG) */

#define ICR_BMDST_OFFSET	0x24
#define ICR_BMDST_MASK		0xFFFFFFFC
#define ICR_BMDST_MIN		ICR_NO_MIN
#define ICR_BMDST_MAX		ICR_NO_MAX
#define ICR_BMDST_INIT		0x00000000

/*    u_long	bmxc;		Bus Master Transfer Count */
/*                              0:20(2Mb)/ 0:21(4Mb) - R/W (IC-PCI)
                                                       R/O (PC-DIG) */

#define ICR_BMXC_OFFSET		0x28
#define ICR_BMXC_MASK 		0x001FFFFF
#define ICR_BMXC_MIN		ICR_NO_MIN
#define ICR_BMXC_MAX		ICR_BMXC_MASK
#define ICR_BMXC_INIT		0x00000000

/*    u_long	reserved_2[3];	not used 0x2C, 0x30, 0x34 */

/*    u_long	intctl;		Interrupt Control Status */
/*-------------------------------------------------------*/

#define ICR_INTCTL_OFFSET	0x38
#define ICR_INTCTL_INIT		0x00360F00

				/* PCI Interrupt Disable */
				/* Bus Master Transfer Done Interrupt
				   Disable */
				/* Clear PCI Interrupt Status R/W1C */
				/* Clear Bus Master Transfer Done Interrupt
				   R/W1C */
				/* Clear Master Abort Interrupt Status
				   R/W1C */
				/* Clear Target Abort Interrupt Status
				   R/W1C */

#define ICR_IRQ_TEST_MASK	0x00360000;	/* here are intr. status bits
						   see test_and_clear_irq */

/*    u_long	zero_1:8;	reset to 0 */
/*    u_long	one_1:4;	set to 1 */

/*    u_long    inten:1;	PCI Interrupt Enable R/W */

#define ICR_INTEN_MASK		0x00001000
#define ICR_INTEN_SHIFT		12

/*    u_long	zero_2:1;	reset to 0  */
/*    u_long	binten:1;	Interrupt on Bus Mater Transfer */
				/* Done Enable R/W */

#define ICR_BINTEN_MASK		0x00004000
#define ICR_BINTEN_SHIFT	14

/*    u_long	res_1:2;	reserved - reset to 0 */
/*    u_long	intst:1;	PCI Interrupt Status R/W1C */

#define ICR_INTST_MASK		0x00020000
#define ICR_INTST_SHIFT		17

/*    u_long	bintst:1;	Bus Master Interrupt Status R/W1C */

#define ICR_BINTST_MASK		0x00040000
#define ICR_BINTST_SHIFT	18

/*    u_long	res_2:1;	reserved - reset to 0 */
/*    u_long	maint:1;	Master Abort Interrupt Status R/W1C */

#define ICR_MAINT_MASK		0x00100000
#define ICR_MAINT_SHIFT		20

/*    u_long	taint:1;	Target Abort Interrupt Status R/W1C */

#define ICR_TAINT_MASK		0x00200000
#define ICR_TAINT_SHIFT		21

/*    u_long	zero_3:1;	reset to 0  */
/*    u_long	res_3:1;	reserved - reset to 0 */
/*    u_long	zero_4:1;	reset to 0  */

/*    u_long	flip:1;		Data Byte Swap (AMCC S5933QE only!?) */
/*                              we assume IC-PCI REV-B boards support this */

#define ICR_FLIP_MASK		0x02000000
#define ICR_FLIP_SHIFT		25

/*    u_long	zero_5:6;	reset to 0  */

/*    u_long	bmctl;		Bus Master Host Control/Status */
/*-------------------------------------------------------------*/

#define ICR_BMCTL_OFFSET	0x3C
#define ICR_BMCTL_INIT		0x04000300
				/* Bus Request Disable */
				/* Disable Software Reset */
				/* FIFO Clear*/

/*    u_long	res_1:3;	reserved - reset to 0 */
/*    u_long	fifofl:1;	FIFO Full (8 x 32bit) R-O */

#define ICR_FIFOFL_MASK		0x00000008
#define ICR_FIFOFL_SHIFT	3

/*    u_long	fifo4p:1;	FIFO Half Full (4 x 32bit) R-O */

#define ICR_FIFO4P_MASK		0x00000010
#define ICR_FIFO4P_SHIFT	4

/*     u_long	fifoem:1;	FIFO Empty (0 x 32bit) R-O */

#define ICR_FIFOEM_MASK		0x00000020
#define ICR_FIFOEM_SHIFT	5

/*    u_long	res_2:1;	reserved - reset to 0 */
/*    u_long	bmdone:1;	Bus Master Transfer Done R-O */

#define ICR_BMDONE_MASK		0x00000080
#define ICR_BMDONE_SHIFT	7

/*    u_long	bmreq:3;	Bus Request R/W IC-PCI Only! */

#define ICR_BMREQ_MASK		0x00000400
#define ICR_BMREQ_SHIFT		10

/* since the revised manual (March 1998) these are also the offical values */
#define ICR_STOP_TRANS		0x00000300
#define ICR_STRT_TRANS		0x00000400

/*    u_long	zero_1:13;	reset to 0 */
/*    u_long	rst:1;		Software Reset R/W */

#define ICR_RST_MASK		0x01000000
#define ICR_RST_SHIFT		24

/*    u_long	res_3:1;	reserved - reset to 0 */
/*    u_long	fifclr:1;	FIFO Clear W-O */

#define ICR_FIFOCLR_MASK	0x04000000
#define ICR_FIFOCLR_SHIFT	26

/*    u_long	res_4:1;	reserved - reset to 0 */
/*    u_long	zero_2:4;	reset to 0 */

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* linux && __KERNEL__ || !OS_DEFINED */

#endif /* _ITIFGREG_H */

